@@ -5,6 +5,10 @@ use Moose::Role;
 requires 'provide_link';
 with 'OpenERP::OOM::DynamicUtils';
 
+sub close_connections
+{
+}
+
 =head1 NAME
 
 OpenERP::OOM::Link::Provider
@@ -38,6 +42,12 @@ normally a DBIC dataset.
 
     1;
 
+=head1 METHODS
+
+=head2 close_connections
+
+This method should close any open database connections held by the link provider.
+
 =head1 COPYRIGHT and LICENSE
 
 Copyright (C) 2011 OpusVL
